(insert-file "insert_file.input")
(save-buffer)
(save-buffers-kill-emacs)
